# frozen_string_literal: true

# app/hermes/models/concerns/common_field.rb
# app/controllers/concerns/test_concern.rb

module Hermes
  module Concerns
    # Handles statuses relationships
    module CommonFieldsConcern
      extend ActiveSupport::Concern

      included do
        include Mongoid::Document
        include Mongoid::Timestamps

        belongs_to(:user, index: true, optional: true)
        include ::AclProtected # evoluera certainement
        writer_auth_roles 'superadministrateur'
        index(readers: 1)
        index(writers: 1)
        index({ "created_at" => 1 }, background: true)
        index({ "updated_at" => 1 }, background: true)

        def responsible=(id)
          self.user_id = id
        end
      end

      module ClassMethods
        # simplify indexes generation
        def common_indexes(*arr_of_sym)
          # pass an array of symbol containing every field.name you need as index
          arr_of_sym.each { |field| index({ field => 1 }, background: true) }
        end
      end
    end
  end
end
