# frozen_string_literal: true

AsyncNotifierJob.class_eval do

  def perform(json_attributes='{}')
    keys = ::NotificationCenter::Notification.fields.keys.map &:to_sym
    attributes = JSON.parse(json_attributes).symbolize_keys.slice(*keys)
    md5_notif_key = Digest::MD5.hexdigest("#{attributes[:title]}#{attributes[:body]}#{attributes[:targetable_id]}")
    # Prevent case of notification has already been created
    if !$redis.get(md5_notif_key)
      begin
        notif = ::NotificationCenter::Notification.create({
          **attributes,
          notifiable_id: attributes[:notifiable_id].present? ? BSON::ObjectId(attributes[:notifiable_id]) : nil,
          targetable_id: attributes[:targetable_id].present? ? BSON::ObjectId(attributes[:targetable_id]) : nil,
          sender_id: attributes[:sender_id].present? ? BSON::ObjectId(attributes[:sender_id]) : nil
        })

        $redis.set(md5_notif_key, notif.id.to_s)
        $redis.expire(md5_notif_key, 5.minutes)
      rescue => e
        Rails.logger.info "Async notifier error"
        Log.perform_later(
          :code => "ANE",
          :user_id => attributes[:sender_id],
          :action => "Async notifier error #{e.message}",
          domain: 'job',
          level: 'info'
        )
      end
    end
  end
end